@@ -2,11 +2,9 @@
 #ifndef _GLIBMM_INTERFACE_H
 #define _GLIBMM_INTERFACE_H
 
-/* $Id: interface.h,v 1.12 2002/04/22 00:09:25 murrayc Exp $ */
+/* $Id: interface.h,v 1.14 2002/10/11 18:05:43 murrayc Exp $ */
 
-/* interface.h
- *
- * Copyright 2001 Free Software Foundation
+/* Copyright 2002 The gtkmm Development Team
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -23,28 +21,28 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <glibmm/object.h> //Needed by dynamic_casts in callbacks.
+#include <glibmm/object.h>
+
 
 namespace Glib
 {
 
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
 class Interface_Class;
-#endif /* DOXYGEN_SHOULD_SKIP_THIS */
+#endif
 
-//There is no base GInterface struct in Glib, though there is G_TYPE_INTERFACE enum value.
-class Interface : virtual public ObjectBase
+// There is no base GInterface struct in Glib, though there is G_TYPE_INTERFACE enum value.
+class Interface : virtual public Glib::ObjectBase
 {
 public:
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
   typedef Interface       CppObjectType;
   typedef Interface_Class CppClassType;
-  //typedef GTypeInterface  BaseObjectType;
   typedef GTypeInterface  BaseClassType;
 #endif /* DOXYGEN_SHOULD_SKIP_THIS */
 
-  Interface();
-  Interface(GObject *castitem);
+  explicit Interface(const Glib::Interface_Class& interface_class);
+  explicit Interface(GObject* castitem);
   virtual ~Interface();
 
   //void add_interface(GType gtype_implementer);
@@ -53,30 +51,22 @@ public:
   //static Glib::Interface* wrap_new(GTypeInterface*);
 
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
-  static GType get_type();
-#endif /* DOXYGEN_SHOULD_SKIP_THIS */
+  static GType get_type()      G_GNUC_CONST;
+  static GType get_base_type() G_GNUC_CONST;
+#endif
 
   inline GObject* gobj()             { return gobject_; }
   inline const GObject* gobj() const { return gobject_; }
 
 private:
-#ifndef DOXYGEN_SHOULD_SKIP_THIS
-  friend class Interface_Class;
-  static CppClassType interface_class;
-
+  // noncopyable
   Interface(const Interface&);
-  Interface& operator=(const Interface&); // not implemented
-#endif /* DOXYGEN_SHOULD_SKIP_THIS */
-
-protected:
-  //GTypeInterface* ginterface_
-  //Each interface will have it's own name - e.g. ginterface_treemodel_
-  //This means that there will be no clash when using virtual inheritance with MI.
+  Interface& operator=(const Interface&);
 };
 
 RefPtr<ObjectBase> wrap_interface(GObject* object, bool take_copy = false);
 
-} /* namespace Glib */
+} // namespace Glib
 
 #endif /* _GLIBMM_INTERFACE_H */
 
