@@ -2,7 +2,7 @@
 #ifndef _GLIBMM_USTRING_H
 #define _GLIBMM_USTRING_H
 
-/* $Id: ustring.h,v 1.31 2002/05/23 13:52:22 daniel Exp $ */
+/* $Id: ustring.h,v 1.35 2002/10/31 13:03:17 daniel Exp $ */
 
 /* Copyright (C) 2002 The gtkmm Development Team
  *
@@ -102,8 +102,8 @@ public:
   typedef std::bidirectional_iterator_tag   iterator_category;
   typedef gunichar                          value_type;
   typedef std::string::difference_type      difference_type;
+  typedef value_type                        reference;
   typedef void                              pointer;
-  typedef void                              reference;
 
   inline ustring_Iterator();
   inline ustring_Iterator(const ustring_Iterator<std::string::iterator>& other);
@@ -137,21 +137,26 @@ gunichar get_unichar_from_std_iterator(std::string::const_iterator pos);
 
 
 /** Glib::ustring has much the same interface as std::string, but contains
- * Unicode characters encoded as UTF-8.
+ * %Unicode characters encoded as UTF-8.
  *
+ * @par About UTF-8 and ASCII
+ * @par
  * The standard character set ANSI_X3.4-1968&nbsp;-- more commonly known as
  * ASCII&nbsp;-- is a subset of UTF-8.  So, if you want to, you can use
  * Glib::ustring without even thinking about UTF-8.
- *
- * @note Whenever ASCII is mentioned in this manual, we mean the @em real ASCII
+ * @par
+ * Whenever ASCII is mentioned in this manual, we mean the @em real ASCII
  * (i.e. as defined in ANSI_X3.4-1968), which contains only 7-bit characters.
  * Glib::ustring can @em not be used with ASCII-compatible extended 8-bit
  * charsets like ISO-8859-1.  It's a good idea to avoid string literals
- * containing non-ASCII characters (e.g. German umlauts) in source code.
- *
- * You can find a detailed UTF-8 and Unicode FAQ here:
+ * containing non-ASCII characters (e.g. German umlauts) in source code,
+ * or at least you should use UTF-8 literals.
+ * @par
+ * You can find a detailed UTF-8 and %Unicode FAQ here:
  * http://www.cl.cam.ac.uk/~mgk25/unicode.html
  *
+ * @par Glib::ustring vs. std::string
+ * @par
  * Glib::ustring has implicit type conversions to and from std::string.
  * These conversions do @em not convert to/from the current locale (see
  * Glib::locale_from_utf8() and Glib::locale_to_utf8() if you need that).  You
@@ -160,15 +165,36 @@ gunichar get_unichar_from_std_iterator(std::string::const_iterator pos);
  * <tt>std::string::operator[]</tt> might return a byte in the middle of a
  * character, and <tt>std::string::length()</tt> returns the number of bytes
  * rather than characters.  So don't do that without a good reason.
- *
+ * @par
  * In a perfect world the C++ Standard Library would contain a UTF-8 string
  * class.  Unfortunately, the C++ standard doesn't mention UTF-8 at all.  Note
  * that std::wstring is not a UTF-8 string class because it contains only
  * fixed-width characters (where width could be 32, 16, or even 8 bits).
  *
+ * @par Glib::ustring and stream input/output
+ * @par
+ * The stream I/O operators, that is operator<<() and operator>>(), perform
+ * implicit charset conversion to/from the current locale.  If that's not
+ * what you intented (e.g. when writing to a configuration file that should
+ * always be UTF-8 encoded) use ustring::raw() to override this behaviour.
+ * @par
+ * If you're using std::ostringstream to build strings for display in the
+ * user interface, you must convert the result back to UTF-8 as shown below:
+ * @code
+ * std::ostringstream output;
+ * output.imbue(std::locale("")); // use the user's locale for this stream
+ * output << percentage << " % done";
+ * label->set_text(Glib::locale_to_utf8(output.str()));
+ * @endcode
+ *
+ * @par Implementation notes
+ * @par
  * Glib::ustring does not inherit from std::string, because std::string was
  * intended to be a final class.  For instance, it does not have a virtual
- * destructor.
+ * destructor.  Also, a HAS-A relationship is more appropriate because
+ * ustring can't just enhance the std::string interface.  Rather, it has to
+ * reimplement the interface so that all operations are based on characters
+ * instead of bytes.
  */
 class ustring
 {
@@ -301,6 +327,7 @@ public:
 //! @name Erase sub-strings.
 //! @{
 
+  void clear();
   ustring& erase(size_type i, size_type n=npos);
   ustring& erase();
   iterator erase(iterator p);
@@ -317,8 +344,24 @@ public:
   int compare(size_type i, size_type n, const char* rhs, size_type n2) const;
   int compare(size_type i, size_type n, const char* rhs) const;
 
-  /*! Create a unique sorting key for the UTF-8 string. */
+  /*! Create a unique sorting key for the UTF-8 string.  If you need to
+   * compare UTF-8 strings regularly, e.g. for sorted containers such as
+   * <tt>std::set<></tt>, you should consider creating a collate key first
+   * and compare this key instead of the actual string.
+   *
+   * The ustring::compare() methods as well as the relational operators
+   * <tt>==&nbsp;!=&nbsp;<&nbsp;>&nbsp;<=&nbsp;>=</tt> are quite costly
+   * because they have to deal with %Unicode and the collation rules defined by
+   * the current locale.  Converting both operands to UCS-4 is just the first
+   * of several costly steps involved when comparing ustrings.  So be careful.
+   */
   std::string collate_key() const;
+
+  /*! Create a unique key for the UTF-8 string that can be used for caseless
+   * sorting.  <tt>ustr.casefold_collate_key()</tt> results in the same string
+   * as <tt>ustr.casefold().collate_key()</tt>, but the former is likely more
+   * efficient.
+   */
   std::string casefold_collate_key() const;
 
 //! @}
@@ -445,16 +488,35 @@ public:
    */
   bool is_ascii() const;
 
-  /*! "Normalize" the Unicode character representation of the string. */
+  /*! "Normalize" the %Unicode character representation of the string. */
   ustring normalize(NormalizeMode mode = NORMALIZE_DEFAULT_COMPOSE) const;
 
 //! @}
 //! @name Character case conversion.
 //! @{
 
+  /*! Returns a new UTF-8 string with all characters characters converted to
+   * their uppercase equivalent, while honoring the current locale.  The
+   * resulting string may change in the number of bytes as well as in the
+   * number of characters.  For instance, the German sharp&nbsp;s
+   * <tt>"&szlig;"</tt> will be replaced by two characters <tt>"SS"</tt>
+   * because there is no capital <tt>"&szlig;"</tt>.
+   */
   ustring uppercase() const;
+
+  /*! Returns a new UTF-8 string with all characters characters converted to
+   * their uppercase equivalent, while honoring the current locale.  The
+   * resulting string may change in the number of bytes as well as in the
+   * number of characters.
+   */
   ustring lowercase() const;
-  ustring casefold()  const;
+
+  /*! Returns a caseless representation of the UTF-8 string.  The resulting
+   * string doesn't correspond to any particular case, therefore the result
+   * is only useful to compare strings and should never be displayed to the
+   * user.
+   */
+  ustring casefold() const;
 
 //! @}
 
